Learn R Programming

ubiquity (version 1.0.0)

calculate_objective_pso: pso Wrapper for calculate_objective

Description

The psoptim objective function assumes parameters will be a vector and this function converts it to a named list to be consistent with the ubiquity optmization routines.

Usage

calculate_objective_pso(pvect, cfg)

Arguments

pvect

system parameters

cfg

ubiquity system object

Value

objective function value