Takes the variance specified as a string and evaluates it locally, and returns that value
calculate_variance(
SIMINT_parameters,
SIMINT_varstr,
SIMINT_odchunk,
SIMINT_cfg
)system parameters
string containing variance calculation
chunk of observation details containing predictions, observations and the time
ubiquity system object
Variance calculated for a given set of parameters in a model