Learn R Programming

ubiquity (version 1.0.0)

check_steady_state: Verify System Steady State

Description

Takes the output run_simulation_ubiquity and verifies that the system is running at steady state by analyzing the timecourse of all of the states in the system

Usage

check_steady_state(cfg, som)

Arguments

cfg

ubiquity system object

Value

list with name steady_state (boolean indicating weather the system was at steady state) and states a vector of states that have steady state offset.