Learn R Programming

ubiquity (version 1.0.0)

linspace: Implementation of the linspace Function from Matlab

Description

Creates a vector of n elements equally spaced apart.

Usage

linspace(a, b, n = 100)

Arguments

a

initial number

b

final number

n

number of elements (integer >= 2)

Value

vector of numbers from a to b with n linearly spaced apart

Examples

Run this code
# NOT RUN {
linspace(0,100, 20)
# }

Run the code above in your browser using DataLab