Learn R Programming

ubiquity (version 1.0.5)

logspace: Implementation of the logspace Function from Matlab

Description

Creates a vector of n elements logarithmically spaced apart.

Usage

logspace(a, b, n = 100)

Arguments

a

initial number

b

final number

n

number of elements (integer >=2)

Value

vector of numbers from a to b with n logarithmically (base 10) spaced apart

Examples

Run this code
# NOT RUN {
logspace(-2, 3,20)
# }

Run the code above in your browser using DataLab