Retrieves a subset of a NONMEM-ish data set based on a list containing filtering information.
nm_select_records(cfg, values, filter)ubiquity system object
dataframe containing the dataset with column headers
list with element names as headers for values with values from the same header OR'd and values across headers AND'd
subset of dataset
If the dataset has the headings ID, DOSE and SEX and
filter has the following format:
filter = list() filter$ID = c(1:4) filter$DOSE = c(5,10) filter$SEX = c(1)
It would be translated into the boolean filter:
((ID==1) | (ID==2) | (ID==3) | (ID==4)) & ((DOSE == 5) | (DOSE==10)) & (SEX == 1)