powered by
A string can contain any number of prototype functions, and this function will find them and replace them with the actual R code.
parse_patterns(cfg, str)
ubiquity system object
string
String with the prototype functions replaced