Learn R Programming

ubiquity (version 1.0.0)

system_check_requirements: Check For Perl and C Tools

Description

Check the local installation for perl and verify C compiler is installed and working.

Usage

system_check_requirements(checklist = list(perl = list(check = TRUE,
  perlcmd = "perl"), C = list(check = TRUE)), verbose = TRUE)

Arguments

checklist

list with names corresponding to elements of the system to check.

verbose

enable verbose messaging

Value

List fn result of all packages

Examples

Run this code
# NOT RUN {
invisible(system_check_requirements())
# }

Run the code above in your browser using DataLab