Learn R Programming

ubiquity (version 1.0.0)

system_glp_save: Save results from a GLP Study design

Description

Saves files associated with a GLP study.

Usage

system_glp_save(cfg, study_name = "default", rptname = "default",
  output_directory = NULL, prefix = NULL)

Arguments

cfg

ubiquity system object

study_name

name of the study to save ("default")

rptname

short name used to identify the report to attach results to the study in other functions (default)

output_directory

optional location to save results (default value of NULL will use the output folder specified at build time)

prefix

optional string to prepend to files generated (default value of NULL will use study_name)

Value

List with the following names

  • isgood Boolean variable indicating success (TRUE) or failure (FALSE)

  • files List with names of the files exported and values containing the paths to the files

See Also

system_glp_init, system_glp_scenario