Loads datasets at the scripting level from a variable if
data_file is a data.frame or from the the following
formats (based on the file extension)
csv - comma delimited
tab - tab delimited
xls - excel spread sheet
Multiple datasets can be loaded as long as they are given different names. Datasets should be in a NONMEM-ish format with the first row containing the column header names.
system_load_data(cfg, dsname, data_file, data_sheet)ubiquity system object
short name of the dataset to be used to link this dataset to different operations
the file name of the dataset or a data frame containing the data
argument identifying the name of the sheet in an excel file
Ubiquity system object with the dataset loaded