Learn R Programming

ubiquity (version 1.0.3)

system_report_doc_format_section: Formats the Current Document Section

Description

Sets the section format for the content added since the last section content type was defined. This is a wrapper for the body_end_section* functions in officer.

Usage

system_report_doc_format_section(
  cfg,
  rptname = "default",
  section_type = NULL,
  w = NULL,
  h = NULL,
  sep = FALSE,
  widths = NULL,
  space = NULL
)

Arguments

cfg

ubiquity system object

rptname

report name initialized with system_report_init

section_type

type of section to apply, either "columns", "continuous", "landscape", "portrait", "columns", or "columns_landscape"

w

width in inches of the section of the page (NULL)

h

height in inches of the section of the page (NULL)

sep

Boolean value controlling line separating columns (FALSE)

widths

column widths in inches, number of columns set by number of values (NULL)

space

space in inches between columns (NULL)

Value

cfg ubiquity system object with the section added to the body