This will take the output generated during a parameter estimation and append those results to a specified report.
system_report_estimation(cfg, rptname = "default", analysis_name = NULL)ubiquity system object
report name (either PowerPoint or Word)
string containing the name of the estimation analysis and used as a prefix to store the results
ubiquity system object with estimation report appended
system_report_init, the reporting vignette (vignette("Reporting", package = "ubiquity"))
and the estimation vignette (vignette("Estimation", package = "ubiquity"))