Learn R Programming

ubiquity (version 1.0.0)

system_report_fetch: Retrieve the officer Object of a Report

Description

Reports are stored in the ubiquity system object and this provides a method for retrieving them by name. They can then be modified using the officer functions directly.

Usage

system_report_fetch(cfg, rptname = "default")

Arguments

cfg

ubiquity system object

rptname

report name

Value

officer pptx object with the of the report named rptname

See Also

system_report_init and system_report_set