Learn R Programming

ubiquity (version 1.0.0)

system_report_glp: Report GLP Study

Description

Append GLP study design a report

Usage

system_report_glp(cfg, study_title = "Study Title",
  study_name = "default", rptname = "default")

Arguments

cfg

ubiquity system object

study_title

String containing descriptive information about the study

study_name

short name used to identify the study in other functions ("default")

rptname

short name used to identify the report to attach results to the study in other functions ("default")

Value

cfg ubiquity system object with the study report information added