Creates a new officer report based either on the ubiquity template or one specified by the user. Once created, content can then be added.
system_report_init(
cfg,
template = NULL,
rptname = "default",
rpttype = NULL,
meta = NULL
)ubiquity system object
path to template file (NULL will load the default ubiquity template)
report name
type of report to create, can be either NULL, "PowerPoint" or "Word"
list containing metadata identifying relevant indices for slide layouts
ubiquity system object with estimation report initialized
Either the rpttype can be specified or the template. If a report type is specified the internal ubiquity template for that type will be used. If the user specifies a template, the type will be determined from the file extension. If both values are NULL the report type will default to "PowerPoint" internally.
Reporting vignette (vignette("Reporting", package = "ubiquity"))