Learn R Programming

ubiquity (version 1.0.0)

system_report_nca: Report NCA

Description

Appends the results of NCA to a report

Usage

system_report_nca(cfg, rptname = "default", analysis_name = "analysis",
  rows_max = 10, table_headers = TRUE)

Arguments

cfg

ubiquity system object

rptname

name of report to append results to (default 'default')

analysis_name

string containing the name of the analysis (default 'analysis') to archive to files and reference results later

rows_max

maximum number of rows per slide when generating tabular data

table_headers

Boolean variable to add descriptive headers to output tables (default TRUE)

Value

cfg ubiquity system object with the NCA results appended to the specified report and if the analysis name is specified:

See Also

Vignette on NCA (vignette("NCA", package = "ubiquity"))