Learn R Programming

ubiquity (version 1.0.5)

system_report_set: Overwrite officer Object for a Given Report

Description

Replace the report named rptname with the contents in rpt

Usage

system_report_set(cfg, rptname = "default", rpt = NULL)

Arguments

cfg

ubiquity system object

rptname

report name initialized with system_report_init

rpt

officer object

Value

ubiquity system object with rpt as content for rptname

See Also

system_report_init and system_fetch_report