Learn R Programming

ubiquity (version 1.0.0)

system_report_slide_content: Add Slide With Main Body of Content

Description

Creates a report slide with a title and single large area of content

Usage

system_report_slide_content(cfg, title = "Title", sub_title = NULL,
  rptname = "default", content_type = "text", content = "Text")

Arguments

cfg

ubiquity system object

title

string with slide title ("Title")

sub_title

string with slide sub title (codeNULL)

rptname

report name initialized with system_report_init

content_type

type of content for main body of slide

content

content of main body of slide

Value

ubiquity system object with slide added to report

Details

For information on the format of content, see system_report_ph_content.

See Also

system_report_init and the reporting vignette (vignette("Reporting", package = "ubiquity"))