Creates a report slide with a title two columns of content with optional headers over the columns
system_report_slide_two_col(
cfg,
title = "Title",
sub_title = NULL,
rptname = "default",
content_type = "text",
left_content = NULL,
left_content_type = NULL,
right_content = NULL,
right_content_type = NULL,
left_content_header = NULL,
left_content_header_type = "text",
right_content_header = NULL,
right_content_header_type = "text"
)ubiquity system object
string with slide title ("Title")
string with slide sub title (codeNULL)
report name initialized with system_report_init
type of content for body text elements 'list' or 'text'
content of left column
inherits the main 'content_type' above unless you wish to specify an image or table
content of right column
inherits the main 'content_type' above unless you wish to specify an image or table
content of left column header
'text' unless you wish to specify an image or table
content of right column header
'text' unless you wish to specify an image or table
ubiquity system object with slide added to report
For information on the format of content, see system_report_ph_content.
system_report_init and the reporting vignette (vignette("Reporting", package = "ubiquity"))