Elements of slide masters are identified by placeholder labels. As PowerPoint masters are created the labels can be difficult to predict. Word documents are identified by style names. This function will create a layout file identifying all of the elements of each slide master for a PowerPoint template or each paragraph and table style for a Word template.
system_report_view_layout(cfg, rptname = "default", output_file = NULL)ubiquity system object
report name initialized with system_report_init
name of file to place the annotated layout information, set to NULL and it will generate a file named layout with the appropriate extension
officer object with the layout of the template annotated,
system_report_init and the reporting vignette (vignette("Reporting", package = "ubiquity"))