powered by
Wrapper for the onbrand::template_details function, see the help for that function for more information
system_rpt_template_details(cfg, rptname = "default")
list with template information, see template_details for information on the structure of this list.
template_details
ubiquity system object
Report name
template_details and Reporting vignette (vignette("Reporting", package = "ubiquity"))
vignette("Reporting", package = "ubiquity")