Simulates the system at the parameter estimates pest for creating diagnostic plots
system_simulate_estimation_results(pest, cfg, details = FALSE)vector of parameters
ubiquity system object
set TRUE to display information about cohorts as they are simulated (useful for debugging)
observations in a list, see system_od_general when estimation=FALSE
system_define_cohort, system_plot_cohorts
and the vignette on parameter estimation (vignette("Estimation", package = "ubiquity"))