powered by
Mechanism for converting numeric variables into strings for reporting.
var2string(vars, maxlength = 0, nsig_e = 3, nsig_f = 4)
numeric variable or a vector of numeric variables
if this value is greater than zero spaces will be added to the beginning of the string until the total length is equal to maxlength
number of significant figures for scientific notation
number of significant figures for numbers (2.123)
Number as a string padded
# NOT RUN { var2string(pi, nsig_f=20) var2string(.0001121, nsig_e=2, maxlength=10) # }
Run the code above in your browser using DataLab