Learn R Programming

ubiquity (version 1.0.0)

calculate_variance: Calculates the Variance in od_general

Description

Takes the variance specified as a string and evaluates it locally, and returns that value

Usage

calculate_variance(SIMINT_parameters, SIMINT_varstr, SIMINT_odchunk,
  SIMINT_cfg)

Arguments

SIMINT_parameters

system parameters

SIMINT_varstr

string containing variance calculation

SIMINT_odchunk

chunk of observation details containing predictions, observations and the time

SIMINT_cfg

ubiquity system object

Value

Variance calculated for a given set of parameters in a model