<IIV:?> in the System FileInternal function used to generate parameters based on IIV information
generate_parameter(SIMINT_parameters, SIMINT_cfg, SIMINT_PARAMETER_TV,
SIMINT_IIV_VALUE, SIMINT_equation)parameters vector containing the typical values
ubiquity system object
equation relating IIV and typical value to the parameter value with variability
Typical value of the parameter in question
sample from mvr distribution
parameter value with the variability applied