powered by
logspace
Creates a vector of n elements logarithmically spaced apart.
logspace(a, b, n = 100)
initial number
final number
number of elements (integer >=2)
vector of numbers from a to b with n logarithmically (base 10) spaced apart
a
b
n
# NOT RUN { logspace(-2, 3,20) # }
Run the code above in your browser using DataLab