Used to run Population/Monte Carlo simulations with subjects generated from either provided variance/covariance information or a dataset.
simulate_subjects(parameters, cfg,
progress_message = "Simulating Subjects:")list containing the typical value of parameters
ubiquity system object
text string to prepend when called from the ShinyApp
Mapped simulation output with individual predictions, individual parameters, and summary statistics of the parameters. The Vignettes below details on the format of the output.
For more information on setting options for population simulation see the
stochastic section of the system_set_option help file.
Vignette on simulation (vignette("Simulation", package = "ubiquity")) titration (vignette("Titration", package = "ubiquity")) as well as som_to_df