Saves files associated with a GLP study.
system_glp_save(cfg, study_name = "default", rptname = "default",
output_directory = NULL, prefix = NULL)ubiquity system object
name of the study to save ("default")
short name used to identify the report to attach results to the study in other functions (default)
optional location to save results (default value of NULL will use the output folder specified at build time)
optional string to prepend to files generated (default value of NULL will use study_name)
List with the following names
isgood Boolean variable indicating success (TRUE) or failure (FALSE)
files List with names of the files exported and values containing the paths to the files