Learn R Programming

ubiquity (version 1.0.0)

system_new: Create New system.txt File

Description

Copy a blank template (system_file="template") file to the working directory or an example by specifying the following:

  • "template" - Empty system file template

  • "two_cmt_macro" - Two compartment model parameterized in terms of clearances (macro constants)

  • "one_cmt_macro" - One compartment model parameterized in terms of clearances (macro constants)

  • "two_cmt_micro" - Two compartment model parameterized in terms of rates (micro constants)

  • "one_cmt_micro" - One compartment model parameterized in terms of rates (micro constants)

  • "adapt" - Parent/metabolite model taken from the adapt manual used in estimation examples

  • "mab_pk" - General compartmental model of mAb PK from Davda 2014 http://doi.org/10.4161/mabs.29095

  • "pbpk" - PBPK model of mAb disposition in mice from Shah 2012

  • "tmdd" - Model of antibody with target-mediated drug disposition

  • "pwc" - Example showing how to make if/then or piece-wise continuous variables

  • "empty" - Minimal system file used to perform other analyses (e.g, NCA)

Usage

system_new(file_name = "system.txt", system_file = "template",
  overwrite = FALSE, output_directory = getwd())

Arguments

file_name

name of the new file to create

system_file

name of the system file to copy

overwrite

if TRUE the new system file will overwrite any existing files present

output_directory

getwd() directory where system file will be placed

Value

TRUE if the new file was created and FALSE otherwise

Examples

Run this code
# NOT RUN {
# To create an example system file named example_system.txt:
system_new(system_file      = "mab_pk", 
           file_name        = "system_example.txt", 
           overwrite        = TRUE,  
           output_directory = tempdir())
# }

Run the code above in your browser using DataLab