"template" - Empty system file template
"two_cmt_macro" - Two compartment model parameterized in terms of clearances (macro constants)
"one_cmt_macro" - One compartment model parameterized in terms of clearances (macro constants)
"two_cmt_micro" - Two compartment model parameterized in terms of rates (micro constants)
"one_cmt_micro" - One compartment model parameterized in terms of rates (micro constants)
"adapt" - Parent/metabolite model taken from the adapt manual used in estimation examples
"mab_pk" - General compartmental model of mAb PK from Davda 2014 http://doi.org/10.4161/mabs.29095
"pbpk" - PBPK model of mAb disposition in mice from Shah 2012
"tmdd" - Model of antibody with target-mediated drug disposition
"pwc" - Example showing how to make if/then or piece-wise continuous variables
"empty" - Minimal system file used to perform other analyses (e.g, NCA)