Sets the section format for the content added since the last section content type was defined. This is a wrapper for the body_end_section* functions in officer.
system_report_doc_format_section(
cfg,
rptname = "default",
section_type = NULL,
w = NULL,
h = NULL,
sep = FALSE,
widths = NULL,
space = NULL
)ubiquity system object
report name initialized with system_report_init
type of section to apply, either "columns", "continuous", "landscape", "portrait", "columns", or "columns_landscape"
width in inches of the section of the page (NULL)
height in inches of the section of the page (NULL)
Boolean value controlling line separating columns (FALSE)
column widths in inches, number of columns set by number of values (NULL)
space in inches between columns (NULL)
cfg ubiquity system object with the section added to the body