Learn R Programming

ubiquity (version 1.0.0)

system_report_doc_set_ph: Sets Placeholder Content for Word Document Report

Description

Adds or updates content to be substituted for placeholders in the specified report.

For example if you have <HEADER_LEFT> in the header of your document and you wanted to replace it with the text "Upper left" you would do the following:

cfg = system_report_doc_set_ph(cfg, ph_content = "Upper Left" , ph_name = "HEADER_LEFT", ph_location = "header")

Notice the ph_name just has HEADER_LEFT and leaves off the <>

Usage

system_report_doc_set_ph(cfg, rptname = "default", ph_name = NULL,
  ph_content = NULL, ph_location = "body")

Arguments

cfg

ubiquity system object

rptname

report name initialized with system_report_init

ph_name

name of the placeholder

ph_content

content to be replaced

ph_location

location of the placeholder: "body" (default), "header", or "footer"

Value

cfg ubiquity system object with the placeholder content set