Learn R Programming

ubiquity (version 1.0.0)

system_report_estimation: Generate a Report from Parameter Estimation

Description

This will take the output generated during a parameter estimation and append those results to a specified report.

Usage

system_report_estimation(cfg, rptname = "default",
  analysis_name = NULL)

Arguments

cfg

ubiquity system object

rptname

report name

analysis_name

string containing the name of the estimation analysis and used as a prefix to store the results

Value

ubiquity system object with estimation report appended

See Also

system_report_init, the reporting vignette (vignette("Reporting", package = "ubiquity")) and the estimation vignette (vignette("Estimation", package = "ubiquity"))