Append GLP study design a report
system_report_glp(cfg, study_title = "Study Title",
study_name = "default", rptname = "default")ubiquity system object
String containing descriptive information about the study
short name used to identify the study in other functions ("default")
short name used to identify the report to attach results to the study in other functions ("default")
cfg ubiquity system object with the study report information added