Appends the results of NCA to a report
system_report_nca(cfg, rptname = "default", analysis_name = "analysis",
rows_max = 10, table_headers = TRUE)ubiquity system object
name of report to append results to (default 'default')
string containing the name of the analysis (default 'analysis') to archive to files and reference results later
maximum number of rows per slide when generating tabular data
Boolean variable to add descriptive headers to output tables (default TRUE)
cfg ubiquity system object with the NCA results appended to the specified report and if the analysis name is specified:
Vignette on NCA (vignette("NCA", package = "ubiquity"))