system_report_save: Save Report to File
Description
Save the contents of rptname to the file output_file
Usage
system_report_save(cfg, rptname = "default", output_file = NULL)
Arguments
rptname
report name initialized with system_report_init
output_file
file name of saved report
Value
Boolean variable indicating success (TRUE) or failure (FALSE)
Details
If you don't specify an output file it will save the report either
report.pptx or report.docx (depending on the type of report) in the current
directory.