Creates a report slide with a title and single large area of content
system_report_slide_content(cfg, title = "Title", sub_title = NULL,
rptname = "default", content_type = "text", content = "Text")ubiquity system object
string with slide title ("Title")
string with slide sub title (codeNULL)
report name initialized with system_report_init
type of content for main body of slide
content of main body of slide
ubiquity system object with slide added to report
For information on the format of content, see system_report_ph_content.
system_report_init and the reporting vignette (vignette("Reporting", package = "ubiquity"))