Learn R Programming

ubiquity (version 1.0.3)

system_report_slide_two_col: Generate Slide with Two Column Layout

Description

Creates a report slide with a title two columns of content with optional headers over the columns

Usage

system_report_slide_two_col(
  cfg,
  title = "Title",
  sub_title = NULL,
  rptname = "default",
  content_type = "text",
  left_content = NULL,
  left_content_type = NULL,
  right_content = NULL,
  right_content_type = NULL,
  left_content_header = NULL,
  left_content_header_type = "text",
  right_content_header = NULL,
  right_content_header_type = "text"
)

Arguments

cfg

ubiquity system object

title

string with slide title ("Title")

sub_title

string with slide sub title (codeNULL)

rptname

report name initialized with system_report_init

content_type

type of content for body text elements 'list' or 'text'

left_content

content of left column

left_content_type

inherits the main 'content_type' above unless you wish to specify an image or table

right_content

content of right column

right_content_type

inherits the main 'content_type' above unless you wish to specify an image or table

left_content_header

content of left column header

left_content_header_type

'text' unless you wish to specify an image or table

right_content_header

content of right column header

right_content_header_type

'text' unless you wish to specify an image or table

Value

ubiquity system object with slide added to report

Details

For information on the format of content, see system_report_ph_content.

See Also

system_report_init and the reporting vignette (vignette("Reporting", package = "ubiquity"))