SI_TT_RATEThe prototype function SI_TT_RATE provides an abstract interface to this function. Based on the input from SI_TT_RATE
infusion rate inputs will be updated for the current titration time.
system_set_tt_rate(cfg, rate, times, levels, tt_ts, tsinfo,
repdose = "none", interval = 1, number = 0)ubiquity system object
name of the infusion rate to update(Defined in <R:?>)
vector of switching times relative to the current titration time (in time units defined by <R:?>)
vector of infusion rates (in dosing units defined by <R:?>)
list of timescale values for the current titration time
list with timescale information for inputs (bolus, rates, etc)
"none" or "sequence"
interval to repeat in the units defined in <R:?>
number of times to repeat
ubiquity system object with the infusion rates updated.