powered by
With the ubiquity package this function can be used to fetch example files for different sections of the workshop.
workshop_fetch( section = "Simulation", overwrite = FALSE, copy_files = TRUE, output_directory = getwd() )
Name of the section of workshop to retrieve ("Simulation")
if TRUE the new workshop files will overwrite any existing files present (FALSE)
TRUE
FALSE
if TRUE the files will be written to the output_directory, if FALSE only the names and locations of the files will be returned (TRUE)
directory where workshop files will be placed (getwd())
list
Valid sections are "Simulation", "Estimation", "Titration" "Reporting", and "NCA"
# NOT RUN { workshop_fetch("Estimation", output_directory=tempdir(), overwrite=TRUE) # }
Run the code above in your browser using DataLab