Learn R Programming

ubiquity (version 1.0.0)

workshop_fetch: Fetch Ubiquity Workshop Sections

Description

With the ubiquity package this function can be used to fetch example files for different sections of the workshop.

Usage

workshop_fetch(section = "Simulation", overwrite = FALSE,
  output_directory = getwd())

Arguments

section

Name of the section of workshop to retrieve ("Simulation")

overwrite

if TRUE the new system file will overwrite any existing files present

output_directory

directory where workshop files will be placed (getwd())

Value

list

Details

Valid sections are "Simulation", "Estimation", "Titration" "Reporting", and "NCA"

Examples

Run this code
# NOT RUN {
workshop_fetch("Estimation", output_directory=tempdir(), overwrite=TRUE)
# }

Run the code above in your browser using DataLab